/* * Copyright (c) 2016 Regents of the University of California. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
*
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
*
* 3. The names of its contributors may not be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
* A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
* CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
* EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
* PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
* *********************************************************************************************** *
* CARLsim
* created by: (MDR) Micah Richert, (JN) Jayram M. Nageswaran
* maintained by:
* (MA) Mike Avery <averym@uci.edu>
* (MB) Michael Beyeler <mbeyeler@uci.edu>,
* (KDC) Kristofor Carlson <kdcarlso@uci.edu>
* (TSC) Ting-Shuo Chou <tingshuc@uci.edu>
* (HK) Hirak J Kashyap <kashyaph@uci.edu>
*
* CARLsim v1.0: JM, MDR
* CARLsim v2.0/v2.1/v2.2: JM, MDR, MA, MB, KDC
* CARLsim3: MB, KDC, TSC
* CARLsim4: TSC, HK
* CARLsim5: HK, JX, KC
* CARLsim6: LN, JX, KC, KW
*
* CARLsim available from http://socsci.uci.edu/~jkrichma/CARLsim/
* Ver 12/31/2016
*/

#include <carlsim.h>

int main() {
	// ---------------- CONFIG STATE -------------------
	CARLsim sim("current_compare", GPU_MODE, USER, 1, 42);
	int gin = sim.createGroup("input", 1, EXCITATORY_NEURON, 0, GPU_CORES);
	int gout = sim.createGroup("output", 1, EXCITATORY_NEURON, 0, GPU_CORES);
	sim.setNeuronParameters(gin, 0.02f, 0.2f, -65.0f, 8.0f);
	//sim.setNeuronParameters(gout, 0.02f, 0.2f, -51.3055f, 2.5222f);
	// from Fig. 8.27 of dynamical systems book
    sim.setNeuronParameters(gout, 40.0f, 0.0f, 0.25f, 0.0f, -65.0f, 0.0f, 
                                -45.0f, 0.0f, 0.015f, 0.0f, 2.0f, 0.0f, 0.0f, 0.0f, 
                                -55.0f, 0.0f, 50.0f, 0.0f, 0);
	sim.connect(gin, gout, "one-to-one", 0.0, 1.0f, RangeDelay(1), RadiusRF(-1), SYN_FIXED, 1, 1);
	sim.setConductances(true, 6, 150, 5, 150);
	//sim.setConductances(false);
	sim.setIntegrationMethod(FORWARD_EULER, 1);
	sim.setNeuronMonitor(gout,"DEFAULT");
	// ---------------- SETUP STATE -------------------
	sim.setupNetwork();
	sim.setSpikeMonitor(gout,"DEFAULT");
	// ---------------- RUN STATE -------------------
	sim.setExternalCurrent(gout, 110); // from Fig. 8.27 of dynamical systems book
	sim.runNetwork(1,0, true);

	return 0;
}
